==> campsite-2.4.1.tbz: campsite/www-common/html/priv/lang/ru/article_images.php <==
<?php
regGS("Items per page", "Объектов на страницу");
regGS("You do not have the right to add images.", "Вы не имеете права добавления картинок.");
regGS("Image information", "Информация о картинке");
regGS("Attach New Image", "Приложить новую картинку");
regGS("Attach Image To Article", "Приложить картинку к статье");
regGS("Attach Existing Image", "Приложить существующую картинку");
regGS("You do not have the right to change this article.  You may only edit your own articles and once submitted an article can only be changed by authorized users.", "Вы не имеете права изменять эту статью. Вы можете только редактировать собственные статьи, и будучи отправленной, статья может быть изменена только уполномоченным пользователем.");
regGS("Add New Image", "Добавить новую картинку");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Дата<BR><SMALL>(гггг-мм-дд)</SMALL>");
regGS("Please enter a number for the image.", "Пожалуйста введите номер для картинки");
regGS("Please enter a description for the image.", "Пожалуйста введите описание для картинки");
regGS("You must select an image file to upload.", "Вы должны выбрать картинку для загрузки.");
regGS("Change image information", "Измениить информацию о картинке");
regGS("You do not have the right to add images", "Вы не имеете права добавления картинок");
regGS("The image $1 has been added.", "Картинка $1 была успешно добавлена.");
regGS("View image", "Просмотр картинки");
regGS("Unlink", "Отвязать");
regGS("Back to article details", "Назад к подробностям статьи");
regGS("Are you sure you want to delete the image \'$1\'?", "Вы уверены, что хотите удалить картинку \'$1\'?");
regGS("Click one of the ", "");
?>

==> campsite-2.6.1.tbz: campsite/www-common/html/priv/lang/ru/article_images.php <==
<?php 
regGS("You do not have the right to change image information.", "Вы не имеете права изменять информацию о картинке.");
regGS("The image number specified is already in use.", "Указанный номер картинки уже используется.");
regGS("The image has been removed from the article.", "Картинка удалена из статьи.");
regGS("Image '$1' updated.", "Картинка '$1' обновлена.");
regGS("Image '$1' added.", "Картинка '$1' добавлена.");
regGS("Edit article", "Редактировать статью");
regGS("You do not have the right to attach images to articles.", "Вы не имеете права добавлять картинки к статье.");
regGS("You do not have the right to add images.", "Вы не имеете права добавления картинок.");
regGS("Image information", "Информация о картинке");
regGS("Attach New Image", "Приложить новую картинку");
regGS("Attach Image To Article", "Приложить картинку к статье");
regGS("Attach Existing Image", "Приложить существующую картинку");
regGS("Add New Image", "Добавить новую картинку");
regGS("Date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Дата<BR><SMALL>(гггг-мм-дд)</SMALL>");
regGS("Please enter a number for the image.", "Пожалуйста введите номер для картинки");
regGS("Please enter a description for the image.", "Пожалуйста введите описание для картинки");
regGS("You must select an image file to upload.", "Вы должны выбрать картинку для загрузки.");
regGS("Change image information", "Измениить информацию о картинке");
regGS("You do not have the right to add images", "Вы не имеете права добавления картинок");
regGS("Items per page", "Объектов на страницу");
regGS("The image $1 has been added.", "Картинка $1 была успешно добавлена.");
regGS("View image", "Просмотр картинки");
regGS("Unlink", "Отвязать");
regGS("Back to article details", "Назад к подробностям статьи");
regGS("Are you sure you want to delete the image \'$1\'?", "Вы уверены, что хотите удалить картинку \'$1\'?");
regGS("Click one of the ", "");
?>
